#!/bin/sh -x
# resolve links - $0 may be a softlink
PRG="$0"

while [ -h "$PRG" ] ; do
  ls=`ls -ld "$PRG"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '.*/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "$PRG"`/"$link"
  fi
done

PRGDIR=`dirname "$PRG"`

PATH=$PRGDIR/../bin:$PATH
export PATH

HEADREPO=Infomedix-tailor-hg-head
B2_0_3_20REPO=Infomedix-tailor-hg-2_0_3_20
B2_1_5REPO=Infomedix-tailor-hg-2_1_5
COMBINEDREPO=Infomedix-tailor-hg-combined

#TDBUG="-D -v"
TDBUG=
rm -rf *.log Icvs* Infomedix-tailor-hg* tailor.* tmp ~/.cvsps

CVSROOT=xxx
export CVSROOT
if cvs login; then
  exec >> tailor.out 2>&1
  set -x
  # Use tailor to extract the HEAD history into a new repository

  tailor $TDBUG --configfile=Infomedix.tailor
  if [ $? -ne 0 -o ! -d $HEADREPO ]; then
    echo "Convert of HEAD branch failed to create repository"
    exit 1
  fi
  # Get the HG versions where the two interesting branches were split off.
  # We know the date/time stamps from examination of the CVS repository history
  # using "cvs log -N -rv2_0_3_20-PREBRANCH" and "cvs log -N -rv2_1_5_1" 
  # Just hope those tags are correct.
  pushd $HEADREPO
  B2_0_3_20=`hg log | perl -e 'while(<>) {if(/^changeset: *([0-9]*):[a-f0-9]*$/){ $changeset = $1;} if(/Jun 28 03:16:46 2007/) { print "$changeset\n";}}'`
  B2_1_5=`hg log | perl -e 'while(<>) {if(/^changeset: *([0-9]*):[a-f0-9]*$/){ $changeset = $1;} if(/Jan 09 03:54:29 2008/) { print "$changeset\n";}}'`
  popd
  if [ -z "$B2_0_3_20" -o -z "$B2_1_5" ]; then
    echo "Failed to find Mercurial versions for b2_0_3_20 or b2_1_5 branch points"
    exit 1
  fi
  # now clone the repository we have up to the date of the branch
  hg clone --rev $B2_0_3_20 -U $HEADREPO $B2_0_3_20REPO
  if [ $? -ne 0 -o ! -d $B2_0_3_20REPO ]; then
    echo "Clone of HEAD repo failed for b2_0_3_20"
    exit 1
  fi
  tailor $TDBUG --configfile=Infomedix.b2_0_3_20.tailor
  if [ $? -ne 0 ]; then
    echo "Convert of b2_0_3_20 branch failed"
    exit 1
  fi

  hg clone --rev $B2_1_5 -U $HEADREPO $B2_1_5REPO
  if [ $? -ne 0 -o ! -d $B2_1_5REPO ]; then
    echo "Clone of HEAD repo failed for b2_1_5"
    exit 1
  fi
  tailor $TDBUG --configfile=Infomedix.b2_1_5.tailor
  if [ $? -ne 0 ]; then
    echo "Convert of b2_1_5 branch failed"
    exit 1
  fi
  
  # now clone the head repository and pull the branches into it
  hg clone -U $HEADREPO $COMBINEDREPO
  if [ $? -ne 0 -o ! -d $COMBINEDREPO ]; then
    echo "Clone of HEAD repo failed for combined"
    exit 1
  fi
  pushd $COMBINEDREPO
  hg pull ../$B2_0_3_20REPO
  hg pull ../$B2_1_5REPO
  popd
fi
